@@ -258,7 +258,7 @@ sub index {
 -- config/test.pl
 +{
     'DBI' => [
-        'dbi:SQLite:memory:',
+        'dbi:SQLite:dbname=test.db',
         '',
         '',
         +{
@@ -275,7 +275,9 @@ use warnings;
 use parent 'Amon2::ConfigLoader';
 1;
 -- sql/my.sql
+
 -- sql/sqlite3.sql
+
 -- tmpl/index.tt
 [% INCLUDE 'include/header.tt' %]
 
@@ -447,6 +449,15 @@ use Test::More 0.96;
     };
 }
 
+# setup database
+use <%= $module %>;
+open my $fh, "<", "sql/sqlite3.sql" or die "Cannot open file: sql/sqlite3.sql";
+unlink 'test.db' if -f 'test.db';
+my $c = <%= $module %>->new;
+for (grep /\S/, split /;/, do { local $/; <$fh> }) {
+    $c->dbh->do($_);
+}
+
 1;
 -- t/01_root.t
 use strict;
@@ -584,6 +595,7 @@ MANIFEST
 *.old
 nytprof.out
 development.db
+est.db
 END_OF_SRC
 
 &main;exit;
